
/*  Inicio Creacion de procedimientos */

SET ECHO OFF;

/* V_PARTIDO(IDE,F,ESTADO,HI,HF,CGEQL,CGEQV,SRESULTADO) */

/*
    NOMBRE:  P_PARTIDO
    TIPO:    select procedure
    ENTRADA: 
    PROCESO: DETERMINA RESULTADO DE PARTIDO (L -> LOCAL, E -> EMPATE, V -> VISITANTE)
    SALIDA:  IGUAL SALIDA QUE VIEW V_PARTIDO, AGREGA COLUMNA RESULTADO CHAR(1) (L,E,V)
*/
SET TERM !! ;
CREATE PROCEDURE P_PARTIDO
   RETURNS (IDE                 SMALLINT,
            F                   DATE,
            ESTADO              NUMERIC(1,0),
            HI                  TIME,
            HF                  TIME,
            CGEQL               SMALLINT,
            CGEQV               SMALLINT,
            SRESULTADO          VARCHAR(10),
            RESULTADO           CHAR(1)) 
   AS
   BEGIN
      FOR SELECT IDE,F,ESTADO,HI,HF,CGEQL,CGEQV,SRESULTADO
          FROM V_PARTIDO 
          INTO :IDE,:F,:ESTADO,:HI,:HF,:CGEQL,:CGEQV,:SRESULTADO
      DO BEGIN
         IF ( CGEQL > CGEQV ) THEN
            RESULTADO = 'L';
         ELSE IF ( CGEQL = CGEQV ) THEN 
            RESULTADO = 'E';
         ELSE
            RESULTADO = 'V';
         SUSPEND;
      END
   END !!
SET TERM ; !!


/*
    NOMBRE:  P_TABLA
    TIPO:    select procedure
    ENTRADA: 
    PROCESO: RECORRE TABLA DE EQUIPOS Y POR CADA UNO DE ELLOS, UTILIZA P_PARTIDO PARA OBTENER EL
             PUNTAJE POR EQUIPO:
             PARTIDO GANADO 3 PUNTOS
             PARTIDO PERDIDO 0 PUNTOS
             PARTIDO EMPATADO 1 PUNTO
    SALIDA:  IDE,NOMBRE (DE EQUIPO),
             CPG (CANTIDAD PARTIDOS GANADOS),
             CPP (CANTIDAD PARTIDOS PERDIDOS), 
             CPE (CANTIDAD PARTIDOS EMPATADOS),
             PUNTOS
*/
SET TERM !! ;
CREATE PROCEDURE P_TABLA
   RETURNS (IDEQ                      SMALLINT,
            NOMBRE                    VARCHAR(50),
            CPG                       SMALLINT,
            CPP                       SMALLINT,
            CPE                       SMALLINT,
            PUNTOS                    SMALLINT) 
   AS
      DECLARE VARIABLE RESULTADO      CHAR(1);
      DECLARE VARIABLE ROLEQ          CHAR(1);
   BEGIN
      FOR SELECT IDEQ,NOMBRE
          FROM T_EQUIPO
          INTO :IDEQ,:NOMBRE
      DO BEGIN
         CPG = 0;
         CPP = 0;
         CPE = 0;
         PUNTOS = 0;
         FOR SELECT P.RESULTADO,E.ROLEQ
             FROM P_PARTIDO P INNER JOIN T_EQ E ON P.IDE = E.IDE AND P.F = E.F
             WHERE E.IDEQ = :IDEQ AND P.ESTADO = 5
             INTO :RESULTADO,:ROLEQ 
         DO BEGIN
             IF ( RESULTADO = ROLEQ ) THEN  
                CPG = CPG + 1;
             ELSE IF ( RESULTADO = 'E' )   THEN  
                CPE = CPE + 1;
             ELSE CPP = CPP + 1;
         END
         PUNTOS = (CPG * 3) + CPE;
         SUSPEND;
      END
   END !!
SET TERM ; !!


/*
    NOMBRE:  P_PARTIDO_INFO
    TIPO:    execute procedure
    ENTRADA: IDE,F (identificacion de partido)
    PROCESO: DADO UN PARTIDO, OBTIENE SU ESTADO, LOS EQUIPOS (L,V), CANTIDAD DE AUTORIDADES Y JUGADORES, 
             CANTIDAD GOLES LOCALES Y VISITANTES ASOCIADOS
    SALIDA:  EQL (EQUIPO LOCAL),EQV (EQUIPO VISITANTE),CAUT (CANTIDAD AUTORIDADES),
             CJUGL (CANTIDAD JUGADORES EQ. LOCAL),CGL (CANTIDAD GOLES LOCAL),
             CJUGV (CANTIDAD JUGADORES EQ. VISITANTE),CGV (CANTIDAD GOLES VISITANTE),
             ESTADO
*/
SET TERM !! ;
CREATE PROCEDURE P_PARTIDO_INFO (IDE                 SMALLINT,
                                 F                   DATE)
   RETURNS (EQL                 SMALLINT,
            EQV                 SMALLINT,
            CAUT                SMALLINT,
            CJUGL               SMALLINT,
            CGL                 SMALLINT,
            CJUGV               SMALLINT,
            CGV                 SMALLINT,
            ESTADO              NUMERIC(1,0)) 
   AS
            DECLARE VARIABLE    CANT SMALLINT;
   BEGIN
      SELECT IDEQ     FROM T_EQ  WHERE IDE = :IDE AND F = :F AND ROLEQ = 'L'           INTO :EQL;
      SELECT IDEQ     FROM T_EQ  WHERE IDE = :IDE AND F = :F AND ROLEQ = 'V'           INTO :EQV;
      SELECT COUNT(*) FROM T_PA  WHERE IDE = :IDE AND F = :F                           INTO :CAUT;
      SELECT COUNT(*),SUM(PJ.CG) FROM T_PJ PJ INNER JOIN T_JUGADOR J ON PJ.IDJ = J.IDJ 
                                 WHERE IDE = :IDE AND F = :F AND J.IDEQ = :EQL         INTO :CJUGL,:CGL;
      SELECT COUNT(*),SUM(PJ.CG) FROM T_PJ PJ INNER JOIN T_JUGADOR J ON PJ.IDJ = J.IDJ 
                                 WHERE IDE = :IDE AND F = :F AND J.IDEQ = :EQV         INTO :CJUGV,:CGV;
      SELECT ESTADO              FROM T_PARTIDO WHERE IDE = :IDE AND F = :F            INTO :ESTADO;
   END !!
SET TERM ; !!

SHOW PROCEDURES;

SET ECHO ON;

/*  Fin Creacion de procedimientos */
