
/*  Inicio Creacion de tablas */

SET ECHO OFF;

/*

T_EQUIPO(IDEQ,NOMBRE,...)
	PK(IDE)
T_JUGADOR(IDJ,NOMBRE,IDEQ,...)
	PK(IDJ)
	FK IDE -> EQUIPO
T_AUTORIDAD(IDAUT,NOMBRE,...)
	PK(IDE)
T_ESTADIO(IDE,NOMBRE,DIR,...)
	PK(IDE)
T_PARTIDO(IDE,F,ESTADO,HI,HF,CGEQL,CGEQV,...)
	PK(IDE,F)
	FK IDE -> ESTADIO
T_EQ(IDE,F,IDEQ,ROLEQ)
	PK(IDE,F,IDEQ)
	FK IDE,F->PARTIDO
	FK IDEQ -> EQUIPO
	AK(IDEQ,F)
	AK(IDE,F,ROLEQ)
T_PJ(IDE,F,IDJ,PUESTO,CG)
	PK(IDE,F,IDJ)
	FK IDE,F ->PARTIDO
	FK IDJ -> JUGADOR
	AK(F,IDJ)
T_PA(IDE,F,IDA,ROL)
	PK(IDE,F,IDA)
	FK IDE,F ->PARTIDO
	FK IDA -> AUTORIDAD
	AK(F,IDA)
	AK(IDE,F,ROL)

*/

CREATE TABLE T_EQUIPO ( 
   IDEQ   DOM_IDPK ,
   NOMBRE DOM_NOMBRE ,
   CONSTRAINT PK_T_EQUIPO PRIMARY KEY (IDEQ)
);

CREATE TABLE T_JUGADOR ( 
   IDJ    DOM_IDPK ,
   NOMBRE DOM_NOMBRE ,
   IDEQ   DOM_IDPK ,
   CONSTRAINT PK_T_JUGADOR          PRIMARY KEY (IDJ) ,
   CONSTRAINT FK_T_JUGADOR_T_EQUIPO FOREIGN KEY (IDEQ) REFERENCES T_EQUIPO
);


CREATE TABLE T_AUTORIDAD ( 
   IDAUT  DOM_IDPK ,
   NOMBRE DOM_NOMBRE ,
   CONSTRAINT PK_T_AUTORIDAD PRIMARY KEY (IDAUT)
);

CREATE TABLE T_ESTADIO ( 
   IDE       DOM_IDPK ,
   NOMBRE    DOM_NOMBRE ,
   DIRECCION DOM_NOMBRE , 
   TE        VARCHAR(50) ,
   CONSTRAINT PK_T_ESTADIO PRIMARY KEY (IDE)
);

CREATE TABLE T_PARTIDO ( 
   IDE    DOM_IDPK ,
   F      DOM_FECHA , 
   ESTADO DOM_PESTADO ,
   HI     DOM_HORA ,
   HF     DOM_HORA ,
   CONSTRAINT PK_T_PARTIDO           PRIMARY KEY (IDE,F) ,
   CONSTRAINT FK_T_PARTIDO_T_ESTADIO FOREIGN KEY (IDE) REFERENCES T_ESTADIO ,
   CONSTRAINT CK_T_PARTIDO_HS        CHECK ( HI < HF )
);


CREATE TABLE T_EQ ( 
   IDE    DOM_IDPK ,
   F      DOM_FECHA , 
   IDEQ   DOM_IDPK , 
   ROLEQ  DOM_ROLEQ , 
   CONSTRAINT PK_T_EQ           PRIMARY KEY (IDE,F,IDEQ) ,
   CONSTRAINT FK_T_EQ_T_PARTIDO FOREIGN KEY (IDE,F) REFERENCES T_PARTIDO ,
   CONSTRAINT FK_T_EQ_T_EQUIPO  FOREIGN KEY (IDEQ)  REFERENCES T_EQUIPO ,
   CONSTRAINT AK_T_EQ_F         UNIQUE (IDEQ,F) ,
   CONSTRAINT AK_T_EQ_ROL       UNIQUE (IDE,F,ROLEQ) 
);

CREATE TABLE T_PJ ( 
   IDE     DOM_IDPK ,
   F       DOM_FECHA , 
   IDJ     DOM_IDPK , 
   PUESTO  DOM_PUESTO ,
   CG      SMALLINT DEFAULT 0 NOT NULL,
   CONSTRAINT PK_T_PJ           PRIMARY KEY (IDE,F,IDJ) ,
   CONSTRAINT FK_T_PJ_T_PARTIDO FOREIGN KEY (IDE,F) REFERENCES T_PARTIDO ,
   CONSTRAINT FK_T_PJ_T_JUGADOR FOREIGN KEY (IDJ)   REFERENCES T_JUGADOR ,
   CONSTRAINT AK_T_PJ_F_J       UNIQUE (F,IDJ) 
);

CREATE TABLE T_PA ( 
   IDE     DOM_IDPK ,
   F       DOM_FECHA , 
   IDA     DOM_IDPK , 
   ROL     DOM_PAROL ,
   CONSTRAINT PK_T_PA               PRIMARY KEY (IDE,F,IDA) ,
   CONSTRAINT FK_T_PA_T_PARTIDO     FOREIGN KEY (IDE,F) REFERENCES T_PARTIDO ,
   CONSTRAINT FK_T_PA_T_AUTORIDAD   FOREIGN KEY (IDA)   REFERENCES T_AUTORIDAD ,
   CONSTRAINT AK_T_PA_F_AUT         UNIQUE (F,IDA) ,
   CONSTRAINT AK_T_PA_F_AUT_ROL     UNIQUE (IDE,F,ROL) 
);

SHOW TABLES;

SET ECHO ON;

/*  Fin Creacion de tablas */
