
/*  Inicio Creacion de triggers */

SET ECHO ON;
/*
    NOMBRE:  TRG_BIT_PARTIDO
    TABLA:   T_PARTIDO
    TIPO:    BI
    PROCESO: TODO PARTIDO DEBE COMENZAR CON ESTADO = 0
*/
SET ECHO OFF;
SET TERM !! ;
CREATE TRIGGER TRG_BIT_PARTIDO  FOR T_PARTIDO
   BEFORE INSERT
   AS
   BEGIN
      NEW.ESTADO = 0;
   END !!
SET TERM ; !!

SET ECHO ON;
/*
    NOMBRE:  TRG_BUT_PARTIDO
    TABLA:   T_PARTIDO
    TIPO:    BU
    PROCESO: 
        -NO PERMITO CAMBIO DE CLAVE PRIMARIA (IDE,F)
       VERIFICO CAMBIOS DE ESTADO PERMITIDOS:
        -LOS CAMBIOS DE ESTADO SON ASCENDENTES, DE 1 EN 1 O BIEN DESCENDENTES DE 1 EN 1
        -UNA VEZ QUE EL PARTIDO QUEDA EN ESTADO 5, NO SE PERMITEN CAMBIOS
        -PARA PASAR DE ESTADO 0 A 1 ->debe haber 2 equipos asociados
                    DE ESTADO 1 A 2 ->debe haber 3 autoridades asociadas
                    DE ESTADO 2 A 3 ->debe haber 11 jugadores por equipo asociados
                    DE ESTADO 3 A 4 ->debe haber un maximo de 14 jugadores por equipo asociados (11 titulares + 3 cambios)
                                    ->debe haber un minimo de 11 jugadores por equipo
        
        - controlar altas y bajas en pj,pa,eq de acuerdo con estado:
           -SOLO SE PUEDEN HACER ALTAS Y BAJAS EN T_EQ SI ESTADO ES 0
           -SOLO SE PUEDEN HACER ALTAS Y BAJAS EN T_PA SI ESTADO ES 0,1
           -SOLO SE PUEDEN HACER ALTAS Y BAJAS EN T_PJ SI ESTADO ES 0,1,2
        restricciones:
           -no permitir cambios de pk en hijos (pj,pa,eq)
        

       

*/
SET ECHO OFF;
SET TERM !! ;
CREATE TRIGGER TRG_BUT_PARTIDO  FOR T_PARTIDO
   BEFORE UPDATE
   AS
      DECLARE VARIABLE CANT                  SMALLINT;
      DECLARE VARIABLE IDEQ                  SMALLINT;
   BEGIN
      IF ( OLD.ESTADO = 5 ) THEN EXCEPTION EX_ESTADO2;
      IF ( OLD.IDE <> NEW.IDE OR OLD.F <> NEW.F ) THEN EXCEPTION EX_T_PARTIDO1; -- INTENTA CAMBIAR PK
      IF ( NEW.ESTADO <> OLD.ESTADO) THEN BEGIN -- HAY CAMBIO DE ESTADO (ASC O DESC)
         IF ( ABS(NEW.ESTADO - OLD.ESTADO) <> 1 ) THEN EXCEPTION EX_ESTADO1; -- EL CAMBIO NO SE HACE DE 1 EN 1
         IF ( OLD.ESTADO = 0 AND NEW.ESTADO = 1 ) THEN BEGIN
            SELECT COUNT(*) FROM T_EQ PE WHERE PE.IDE = OLD.IDE AND PE.F = OLD.F INTO :CANT;
            IF ( CANT IS NULL ) THEN EXCEPTION EX_T_EQ1; -- NO HAY NINGUN EQUIPO
            IF ( CANT <> 2 )    THEN EXCEPTION EX_T_EQ1; -- NO HAY 2 EQUIPOS
         END 
         IF ( OLD.ESTADO = 1 AND NEW.ESTADO = 2 ) THEN BEGIN
            SELECT COUNT(*) FROM T_PA PE WHERE PE.IDE = OLD.IDE AND PE.F = OLD.F INTO :CANT;
            IF ( CANT IS NULL ) THEN EXCEPTION EX_T_PA1; -- NO HAY NINGUN ARBITRO
            IF ( CANT <> 3 )    THEN EXCEPTION EX_T_PA1; -- NO HAY 3 ARBITROS
         END 
         IF ( OLD.ESTADO = 2 AND NEW.ESTADO = 3 ) THEN BEGIN
            FOR SELECT J.IDEQ,COUNT(PJ.IDE)
                FROM T_PJ PJ INNER JOIN T_JUGADOR J ON PJ.IDJ = J.IDJ
                WHERE PJ.IDE = OLD.IDE AND PJ.F = OLD.F 
                GROUP BY J.IDEQ
                INTO :IDEQ,:CANT  
            DO BEGIN
               IF ( CANT <> 11 )    THEN EXCEPTION EX_T_PJ1; -- NO HAY 11 JUGADORES POR EQUIPO
            END
         END 
         IF ( OLD.ESTADO = 3 AND NEW.ESTADO = 4 ) THEN BEGIN
            FOR SELECT J.IDEQ,COUNT(PJ.IDE)
                FROM T_PJ PJ INNER JOIN T_JUGADOR J ON PJ.IDJ = J.IDJ
                WHERE PJ.IDE = OLD.IDE AND PJ.F = OLD.F 
                GROUP BY J.IDEQ
                INTO :IDEQ,:CANT  
            DO BEGIN
               IF ( CANT < 11 OR CANT > 14 )    THEN EXCEPTION EX_T_PJ4; -- NO HAY entre 11 y 14 JUGADORES POR EQUIPO
            END
         END 
      END 
   END !!
SET TERM ; !!

SET ECHO ON;
/*
    NOMBRE:  TRG_BIT_EQ
    TABLA:   T_EQ
    TIPO:    BI
    PROCESO: SOLO SE PUEDEN HACER ALTAS EN T_EQ SI EL ESTADO DEL PARTIDO ES 0

*/
SET ECHO OFF;
SET TERM !! ;
CREATE TRIGGER TRG_BIT_EQ  FOR T_EQ
   BEFORE INSERT
   AS
      DECLARE VARIABLE ESTADO NUMERIC(1,0);
   BEGIN
      SELECT ESTADO FROM T_PARTIDO WHERE IDE = NEW.IDE AND F = NEW.F INTO :ESTADO;
      IF ( ESTADO IS NULL ) THEN EXCEPTION EX_T_PARTIDO6;
      IF ( ESTADO <> 0 ) THEN EXCEPTION EX_T_PARTIDO3;
   END !!
SET TERM ; !!

SET ECHO ON;
/*
    NOMBRE:  TRG_BDT_EQ
    TABLA:   T_EQ
    TIPO:    BD
    PROCESO: SOLO SE PUEDEN HACER BAJAS EN T_EQ SI EL ESTADO DEL PARTIDO ES 0

*/
SET ECHO OFF;
SET TERM !! ;
CREATE TRIGGER TRG_BDT_EQ  FOR T_EQ
   BEFORE DELETE
   AS
      DECLARE VARIABLE ESTADO NUMERIC(1,0);
   BEGIN
      SELECT ESTADO FROM T_PARTIDO WHERE IDE = OLD.IDE AND F = OLD.F INTO :ESTADO;
      IF ( ESTADO IS NULL ) THEN EXCEPTION EX_T_PARTIDO6;
      IF ( ESTADO <> 0 ) THEN EXCEPTION EX_T_PARTIDO3;
   END !!
SET TERM ; !!

SET ECHO ON;
/*
    NOMBRE:  TRG_BUT_EQ
    TABLA:   T_EQ
    TIPO:    BU
    PROCESO: NO PERMITO QUE SE CAMBIE PK (IDE,F,IDEQ)

*/
SET ECHO OFF;
SET TERM !! ;
CREATE TRIGGER TRG_BUT_EQ  FOR T_EQ
   BEFORE UPDATE
   AS
   BEGIN
      IF ( OLD.IDE <> NEW.IDE OR OLD.F <> NEW.F OR OLD.IDEQ <> NEW.IDEQ ) THEN EXCEPTION EX_T_EQ2; -- INTENTA CAMBIAR PK
   END !!
SET TERM ; !!


SET ECHO ON;
/*
    NOMBRE:  TRG_BIT_PJ
    TABLA:   T_PJ
    TIPO:    BI
    PROCESO: SOLO PERMITO RELACIONAR JUGADORES QUE SEAN DE LOS EQUIPOS DEL PARTIDO EN CUESTION
             NO PERMITO AGREGAR JUGADORES SI EL PARTIDO ESTA EN ESTADO 5 (TERMINADO)

*/
SET ECHO OFF;
SET TERM !! ;
CREATE TRIGGER TRG_BIT_PJ  FOR T_PJ
   BEFORE INSERT
   AS
      DECLARE VARIABLE CANT                  SMALLINT;
      DECLARE VARIABLE IDEQ                  SMALLINT;
   BEGIN
      SELECT ESTADO FROM T_PARTIDO WHERE IDE = NEW.IDE AND F = NEW.F INTO :CANT;
      IF ( CANT IS NULL ) THEN EXCEPTION EX_T_PARTIDO6;
      IF ( CANT NOT IN(0,1,2) ) THEN EXCEPTION EX_T_PARTIDO5;
      SELECT IDEQ   FROM T_JUGADOR WHERE IDJ = NEW.IDJ INTO :IDEQ; -- EQUIPO DEL JUGADOR
      IF ( IDEQ IS NOT NULL ) THEN BEGIN
         SELECT COUNT(*) FROM T_EQ WHERE IDE = NEW.IDE AND F = NEW.F AND IDEQ = :IDEQ INTO :CANT; -- EQ PARTIDO = JUGADOR?
         IF ( CANT IS NULL ) THEN EXCEPTION EX_T_PJ2;
         IF ( CANT <> 1 )    THEN EXCEPTION EX_T_PJ2;
      END -- PODRIA SALIR POR AQUI?? ->TP 7
   END !!
SET TERM ; !!

SET ECHO ON;
/*
    NOMBRE:  TRG_BDT_PJ
    TABLA:   T_PJ
    TIPO:    BD
    PROCESO: SOLO SE PUEDEN HACER BAJAS EN T_PJ SI EL ESTADO DEL PARTIDO ES 0,1,2

*/
SET ECHO OFF;
SET TERM !! ;
CREATE TRIGGER TRG_BDT_PJ  FOR T_PJ
   BEFORE DELETE
   AS
      DECLARE VARIABLE ESTADO NUMERIC(1,0);
   BEGIN
      SELECT ESTADO FROM T_PARTIDO WHERE IDE = OLD.IDE AND F = OLD.F INTO :ESTADO;
      IF ( ESTADO IS NULL ) THEN EXCEPTION EX_T_PARTIDO6;
      IF ( ESTADO NOT IN(0,1,2) ) THEN EXCEPTION EX_T_PARTIDO5;
   END !!
SET TERM ; !!


SET ECHO ON;
/*
    NOMBRE:  TRG_BUT_PJ
    TABLA:   T_PJ
    TIPO:    BU
    PROCESO: NO PERMITO QUE SE CAMBIE PK (IDE,F,IDJ)

*/
SET ECHO OFF;
SET TERM !! ;
CREATE TRIGGER TRG_BUT_PJ  FOR T_PJ
   BEFORE UPDATE
   AS
   BEGIN
      IF ( OLD.IDE <> NEW.IDE OR OLD.F <> NEW.F OR OLD.IDJ <> NEW.IDJ ) THEN EXCEPTION EX_T_PJ3; -- INTENTA CAMBIAR PK
   END !!
SET TERM ; !!


SET ECHO ON;
/*
    NOMBRE:  TRG_BIT_PA
    TABLA:   T_PA
    TIPO:    BI
    PROCESO: SOLO SE PUEDEN HACER ALTAS EN T_PA SI EL ESTADO DEL PARTIDO ES 0,1

*/
SET ECHO OFF;
SET TERM !! ;
CREATE TRIGGER TRG_BIT_PA  FOR T_PA
   BEFORE INSERT
   AS
      DECLARE VARIABLE ESTADO NUMERIC(1,0);
   BEGIN
      SELECT ESTADO FROM T_PARTIDO WHERE IDE = NEW.IDE AND F = NEW.F INTO :ESTADO;
      IF ( ESTADO IS NULL ) THEN EXCEPTION EX_T_PARTIDO6;
      IF ( ESTADO NOT IN(0,1) ) THEN EXCEPTION EX_T_PARTIDO4;
   END !!
SET TERM ; !!

SET ECHO ON;
/*
    NOMBRE:  TRG_BDT_PA
    TABLA:   T_PA
    TIPO:    BD
    PROCESO: SOLO SE PUEDEN HACER BAJAS EN T_PA SI EL ESTADO DEL PARTIDO ES 0,1

*/
SET ECHO OFF;
SET TERM !! ;
CREATE TRIGGER TRG_BDT_PA  FOR T_PA
   BEFORE DELETE
   AS
      DECLARE VARIABLE ESTADO NUMERIC(1,0);
   BEGIN
      SELECT ESTADO FROM T_PARTIDO WHERE IDE = OLD.IDE AND F = OLD.F INTO :ESTADO;
      IF ( ESTADO IS NULL ) THEN EXCEPTION EX_T_PARTIDO6;
      IF ( ESTADO NOT IN(0,1) ) THEN EXCEPTION EX_T_PARTIDO4;
   END !!
SET TERM ; !!



SET ECHO ON;
/*
    NOMBRE:  TRG_BUT_PA
    TABLA:   T_PA
    TIPO:    BU
    PROCESO: NO PERMITO QUE SE CAMBIE PK (IDE,F,IDA)

*/
SET ECHO OFF;
SET TERM !! ;
CREATE TRIGGER TRG_BUT_PA  FOR T_PA
   BEFORE UPDATE
   AS
   BEGIN
      IF ( OLD.IDE <> NEW.IDE OR OLD.F <> NEW.F OR OLD.IDA <> NEW.IDA ) THEN EXCEPTION EX_T_PA2; -- INTENTA CAMBIAR PK
   END !!
SET TERM ; !!


SHOW TRIGGERS;

SET ECHO ON;

/*  Fin Creacion de triggers */
